@@ -35,9 +35,61 @@
 #include "charset.h"
 
 #ifndef EILSEQ
-#define EILSEQ EINVAL
+# define EILSEQ EINVAL
 #endif
 
+#ifdef HAVE_LANGINFO_CODESET
+# include <langinfo.h>
+
+/* 
+ * Try to convert nl_langinfo's return value to something we can
+ * use for MIME's purposes.
+ *
+ * Note that the algorithm used here is quite different from the
+ * one in mutt_canonical_charset. 
+ */
+
+void mutt_set_langinfo_charset (void)
+{
+  char buff[LONG_STRING];
+  char buff2[LONG_STRING];
+  char *s, *d, *cp;
+  
+  strfcpy (buff, nl_langinfo (CODESET), sizeof (buff));
+  strfcpy (buff2, buff, sizeof (buff2));
+  
+  /* compactify the character set name returned */
+  for (d = s = buff; *s; s++)
+  {
+    if (!strchr ("-_.", *s))
+      *d++ = *s;
+  }
+  *d = '\0';
+  
+  /* look for common prefixes which may have been done wrong */
+  if (!strncasecmp (buff, "iso8859", 7))
+  {
+    snprintf (buff2, sizeof (buff2), "iso-8859-%s", buff + 7);
+    if ((cp = strchr (buff2, ':')))	/* strip :yyyy suffixes */
+      *cp = '\0';
+  }
+  else if (!strncasecmp (buff, "koi8", 4))
+  {
+    snprintf (buff2, sizeof (buff2), "koi8-%s", buff + 4);
+  }
+  else if (!strncasecmp (buff, "windows", 7))
+  {
+    snprintf (buff2, sizeof (buff2), "windows-%s", buff + 7);
+  }
+
+  /* fix the spelling */
+  mutt_canonical_charset (buff, sizeof (buff), buff2);
+  
+  /* finally, set $charset */
+  Charset = safe_strdup (buff);
+}
+
+#endif
 
 void mutt_canonical_charset (char *dest, size_t dlen, const char *name)
 {
@@ -79,9 +131,16 @@ iconv_t mutt_iconv_open (const char *tocode, const char *fromcode)
 {
   char tocode1[SHORT_STRING];
   char fromcode1[SHORT_STRING];
+  char *tmp;
 
   mutt_canonical_charset (tocode1, sizeof (tocode1), tocode);
+  if ((tmp = mutt_charset_hook (tocode1)))
+    mutt_canonical_charset (tocode1, sizeof (tocode1), tmp);
+
   mutt_canonical_charset (fromcode1, sizeof (fromcode1), fromcode);
+  if ((tmp = mutt_charset_hook (fromcode1)))
+    mutt_canonical_charset (fromcode1, sizeof (fromcode1), tmp);
+
   return iconv_open (tocode1, fromcode1);
 }
 
@@ -456,7 +515,7 @@ FGETCONV *fgetconv_open (FILE *file, const char *from, const char *to)
 {
   struct fgetconv_s *fc;
   iconv_t cd = (iconv_t)-1;
-  const char *repls[] = { "\357\277\275", "?", 0 };
+  static const char *repls[] = { "\357\277\275", "?", 0 };
 
   if (from && to)
     cd = mutt_iconv_open (to, from);
