@@ -57,6 +57,7 @@ int mutt_recode_file (const char *, const char *, const char *);
 
 int mutt_convert_string (char **, const char *, const char *);
 
+iconv_t mutt_iconv_open (const char *, const char *);
 size_t mutt_iconv (iconv_t, const char **, size_t *, char **, size_t *, const char **, const char *);
 
 typedef void * FGETCONV;
@@ -65,4 +66,8 @@ FGETCONV *fgetconv_open (FILE *, const char *, const char *);
 int fgetconv (FGETCONV *);
 void fgetconv_close (FGETCONV *);
 
+#ifdef HAVE_LANGINFO_CODESET
+void mutt_set_langinfo_charset (void);
+#endif
+
 #endif /* _CHARSET_H */
