@@ -226,7 +226,7 @@ int imap_reopen_mailbox (CONTEXT *ctx, int *index_hint)
       pc = buf + 2;
 
       if (!mutt_strncasecmp ("STATUS", pc, 6) &&
-	  (pc = mutt_stristr (pc, "MESSAGES")))
+	  (pc = (char *) mutt_stristr (pc, "MESSAGES")))
       {
 	char* pn;
 	
@@ -650,7 +650,6 @@ int imap_open_mailbox (CONTEXT *ctx)
     ctx->readonly = 1;
   }
 
-#ifdef DEBUG
   /* dump the mailbox flags we've found */
   if (debuglevel > 2)
   {
@@ -671,7 +670,6 @@ int imap_open_mailbox (CONTEXT *ctx)
       dprint (3, (debugfile, "\n"));
     }
   }
-#endif
 
   if (!imap_code (buf))
   {
