@@ -139,12 +139,12 @@ int imap_parse_path (const char *path, IMAP_MBOX *mx)
   {
     return -1;
   }
-  c = strchr (path, '}');
-  if (!c)
+  mx->mbox = strchr (path, '}');
+  if (!(mx->mbox))
     return -1;
   else
     /* walk past closing '}' */
-    mx->mbox = strdup (c+1);
+    (mx->mbox)++;
   
   /* Defaults */
   mx->flags = 0;
