@@ -19,6 +19,7 @@
 #include "config.h"
 
 #include <stdio.h>
+#include <stdlib.h>
 #ifdef HAVE_UNISTD_H
 # include <unistd.h> /* needed for SEEK_SET */
 #endif
@@ -318,6 +319,7 @@ enum
   OPTSSLV2,
   OPTSSLV3,
   OPTTLSV1,
+  OPTSSLSYSTEMCERTS,
 #endif
   OPTIMPLICITAUTOVIEW,
   OPTMAILCAPSANITIZE,
