@@ -33,6 +33,9 @@
 #include <sys/stat.h>
 #include <sys/wait.h>
 #include <dirent.h>
+#include <time.h>
+#include <sys/types.h>
+#include <utime.h>
 
 #ifdef HAVE_PGP
 #include "pgp.h"
@@ -951,14 +954,12 @@ static int send_message (HEADER *msg)
 static void encode_descriptions (BODY *b, short recurse)
 {
   BODY *t;
-  char tmp[LONG_STRING];
 
   for (t = b; t; t = t->next)
   {
     if (t->description)
     {
-      rfc2047_encode_string (tmp, sizeof (tmp), (unsigned char *) t->description);
-      mutt_str_replace (&t->description, tmp);
+      rfc2047_encode_string (&t->description);
     }
     if (recurse && t->parts)
       encode_descriptions (t->parts, recurse);
@@ -1225,9 +1226,20 @@ ci_send_message (int flags,		/* send mode */
   {
     struct stat st;
     time_t mtime;
+    struct utimbuf utim;
 
     stat (msg->content->filename, &st);
     mtime = st.st_mtime;
+    if (mtime == time (NULL))
+    {
+      /* Decrease the file's modification time by 1 second so we are sure
+       * to find out if the `editor' program changes it in less than 1 second.
+       */
+      mtime -= 1;
+      utim.actime = mtime;
+      utim.modtime = mtime;
+      utime (msg->content->filename, &utim);
+    }
 
     mutt_update_encoding (msg->content);
 
